Watchdog: move get and set watchdog to new api.

Rewrite "get and set watchdog" command to use the newly
introduced ipmi api.

Tested:
Verified using ipmitool "get and set watchdog",
timer behavior is same before and after the changes.

Testing Procedure:
default watchdog timer is 11.2 seconds.

ipmitool raw 0x06 0x25      ---> Get
Output: 00 00 00 00 70 17 70 17

Note: Here 70 count(hex value)->112 count(decimal value)->112*100=11200ms
[100ms per count]->11.2sec (watchdog timer)

watchdog timer set to 20 seconds.

ipmitool raw 0x06 0x24 0x44 0x01 0x00 0x10 0xc8 0x00   ----> Set
output:

ipmitool raw 0x06 0x25    ---> Get
output: 04 01 00 00 c8 00 c8 00

Note: Here 20sec->20000ms->200count->c8 (hex value)

Signed-off-by: Deepak Kumar Sahu <deepakx.sahu@intel.com>
Change-Id: Id8c096bc1635d1900ee842a9726c49fb690fa8bc
diff --git a/app/watchdog.hpp b/app/watchdog.hpp
index 3f91f4f..d52b6e6 100644
--- a/app/watchdog.hpp
+++ b/app/watchdog.hpp
@@ -6,35 +6,40 @@
  */
 ipmi::RspType<> ipmiAppResetWatchdogTimer();
 
 /** @brief The SET watchdog IPMI command.
  *
- *  @param[in] netfn
- *  @param[in] cmd
- *  @param[in] request
- *  @param[in,out] response
- *  @param[out] data_len
- *  @param[in] context
+ * @param
+ * - timerUse
+ * - dontStopTimer
+ * - dontLog
+ * - timerAction
+ * - pretimeout
+ * - expireFlags
+ * - initialCountdown
  *
- *  @return IPMI_CC_OK on success, an IPMI error code otherwise.
- */
-ipmi_ret_t ipmi_app_watchdog_set(ipmi_netfn_t netfn, ipmi_cmd_t cmd,
-                                 ipmi_request_t request,
-                                 ipmi_response_t response,
-                                 ipmi_data_len_t data_len,
-                                 ipmi_context_t context);
+ * @return completion code on success.
+ **/
+ipmi::RspType<> ipmiSetWatchdogTimer(
+    uint3_t timerUse, uint3_t reserved, bool dontStopTimer, bool dontLog,
+    uint3_t timeoutAction, uint1_t reserved1, uint3_t preTimeoutInterrupt,
+    uint1_t reserved2, uint8_t preTimeoutInterval, uint1_t reserved3,
+    uint5_t expFlagValue, uint2_t reserved4, uint16_t initialCountdown);
 
-/** @brief The GET watchdog IPMI command.
- *  @param[in] netfn
- *  @param[in] cmd
- *  @param[in] request
- *  @param[in,out] response
- *  @param[out] data_len
- *  @param[in] context
+/**@brief The getWatchdogTimer ipmi command.
  *
- *  @return IPMI_CC_OK on success, an IPMI error code otherwise.
- */
-ipmi_ret_t ipmi_app_watchdog_get(ipmi_netfn_t netfn, ipmi_cmd_t cmd,
-                                 ipmi_request_t request,
-                                 ipmi_response_t response,
-                                 ipmi_data_len_t data_len,
-                                 ipmi_context_t context);
+ * @return
+ * - timerUse
+ * - timerActions
+ * - pretimeout
+ * - timeruseFlags
+ * - initialCountdown
+ * - presentCountdown
+ **/
+ipmi::RspType<uint8_t,  // timerUse
+              uint8_t,  // timerAction
+              uint8_t,  // pretimeout
+              uint8_t,  // expireFlags
+              uint16_t, // initial Countdown - Little Endian (deciseconds)
+              uint16_t  // present Countdown - Little Endian (deciseconds)
+              >
+    ipmiGetWatchdogTimer();
@@ -6,35 +6,40 @@
 ipmi::RspType<> ipmiAppResetWatchdogTimer();
 
-/** @brief The SET watchdog IPMI command.
+/**@brief The setWatchdogTimer ipmi command.
  *